@@ -52,7 +52,7 @@ void ChartForegroundPainter::setChartCore(ChartCore* chartCore)
         }
 
         triggerUpdate();
-        emit chartCoreChanged();
+        Q_EMIT chartCoreChanged();
     }
 }
 
@@ -67,7 +67,7 @@ void ChartForegroundPainter::setBackgroundColor(const QColor& backgroundColor)
     {
         m_backgroundColor = backgroundColor;
         triggerUpdate();
-        emit backgroundColorChanged();
+        Q_EMIT backgroundColorChanged();
     }
 }
 
@@ -102,4 +102,4 @@ void ChartForegroundPainter::triggerUpdate()
     update();
 }
 
-#include "moc_chartforegroundpainter.cpp"
\ No newline at end of file
+#include "moc_chartforegroundpainter.cpp"
